Index: trunk/ArchTOIPipe/Kernel/toiprocessor.h
===================================================================
--- trunk/ArchTOIPipe/Kernel/toiprocessor.h	(revision 2187)
+++ trunk/ArchTOIPipe/Kernel/toiprocessor.h	(revision 2448)
@@ -5,5 +5,5 @@
 //                               Christophe Magneville
 //                               Reza Ansari
-// $Id: toiprocessor.h,v 1.20 2002-09-09 15:33:15 aubourg Exp $
+// $Id: toiprocessor.h,v 1.21 2003-10-13 20:48:37 aubourg Exp $
 
 
@@ -48,6 +48,6 @@
   virtual void run();
 
-  virtual int   getMinOut();
-  virtual int   getMaxOut();
+  virtual long  getMinOut();
+  virtual long  getMaxOut();
   
   // rajout vf 29/07/2002
@@ -71,7 +71,7 @@
 #ifndef NO_SOPHYA
   /* ---- l'interface va etre modifiee, NE PAS UTILISER
-  Array         getData(int toiIndex, int iStart, int iEnd);
-  Array         getError(int toiIndex, int iStart, int iEnd);
-  TArray<int_4> getFlag(int toiIndex, int iStart, int iEnd);
+  Array         getData(int toiIndex, long iStart, long iEnd);
+  Array         getError(int toiIndex, long iStart, long iEnd);
+  TArray<int_4> getFlag(int toiIndex, long iStart, long iEnd);
           l'interface va etre modifiee, NE PAS UTILISER ---- */
 #endif
@@ -80,22 +80,22 @@
   // Les methodes qui suivent ne peuvent etre 
   // utilisees que sur des entrees simples
-  double        getData(int toiIndex, int i);
-  void          getData(int toiIndex, int i, double &data, uint_8 &flag);
-
-  void          getData(int toiIndex, int i, int n, double* d);
-  void          getData(int toiIndex, int i, int n, double* d, uint_8* f);
-  
-  //RZCMV  double        getError(int toiIndex, int i);
-  //RZCMV  int_4         getFlag(int toiIndex, int i);
-
-  void          wontNeedBefore(int i);
-  int           wontNeedValue;
-  void          setNeededHistory(int nsamples); // -1 : disable
-
-  void          putData(int toiIndex, int i, double value, uint_8 flag=0);
-  //RZCMV  void          putDataError(int toiIndex, int i, double value, 
+  double        getData(int toiIndex, long i);
+  void          getData(int toiIndex, long i, double &data, uint_8 &flag);
+
+  void          getData(int toiIndex, long i, long n, double* d);
+  void          getData(int toiIndex, long i, long n, double* d, uint_8* f);
+  
+  //RZCMV  double        getError(int toiIndex, long i);
+  //RZCMV  int_4         getFlag(int toiIndex, long i);
+
+  void          wontNeedBefore(long i);
+  long           wontNeedValue;
+  void          setNeededHistory(long nsamples); // -1 : disable
+
+  void          putData(int toiIndex, long i, double value, uint_8 flag=0);
+  //RZCMV  void          putDataError(int toiIndex, long i, double value, 
   //RZCMV		             double error, int_4 flag=0);
 
-  void          putData(int toiIndex, int i, int n, double const* val,
+  void          putData(int toiIndex, long i, long n, double const* val,
 			uint_8 const* flg=0);
 
@@ -103,20 +103,20 @@
 public:  
   // Methodes passees en public par Reza, 14/5/2002
-  virtual int   calcMinOut(); // Protected ?
-  virtual int   calcMaxOut(); // Protected ?
-
-  virtual int   getMinIn();
-  virtual int   getMaxIn();
+  virtual long   calcMinOut(); // Protected ?
+  virtual long   calcMaxOut(); // Protected ?
+
+  virtual long   getMinIn();
+  virtual long   getMaxIn();
 protected:
   // Implementation par defaut
-  int           minOut;    // Cache for calcMinOut() value. Protected ?
-  int           maxOut;    // Cache for calcMaxOut() value. Protected ?
+  long           minOut;    // Cache for calcMinOut() value. Protected ?
+  long           maxOut;    // Cache for calcMaxOut() value. Protected ?
 
   int           upExtra;  // MaxIn - MaxOut : extra samples for processing
   int           lowExtra; // MinOut - MinIn : extra samples for processing
 
-  int           forcedMinIn; // to process a subset of data
-  int           forcedMaxIn; // to process a subset of data
-  void          setSampleSubset(int min, int max);
+  long           forcedMinIn; // to process a subset of data
+  long           forcedMaxIn; // to process a subset of data
+  void          setSampleSubset(long min, long max);
 
   int           neededHistory;
@@ -134,6 +134,6 @@
   //  Fin rajout Reza 11/3/2001 
 
-  void          autoWontNeed(int iCur);
-  int           lastAWN;
+  void          autoWontNeed(long iCur);
+  long           lastAWN;
 
 
@@ -158,6 +158,6 @@
   virtual ~TOIProcessor();
   
-  void setMinSn(int n) {forcedMinIn = n;}
-  void setMaxSn(int n) {forcedMaxIn = n;}
+  void setMinSn(long n) {forcedMinIn = n;}
+  void setMaxSn(long n) {forcedMaxIn = n;}
 
   // ajout vf 23/08/2002
